/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Julien Kindle
 *   Co-authors:
 *      
 *
 */

/**
    @file SOBCoin.cc
    @brief This is the object that appears when player hits a QBlock with type coin - it should be a coin floating ontop of the QBlock
*/

#include "SOBCoin.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"
#include "SOBFigure.h"
#include "util/Output.h"


namespace orxonox
{
    RegisterClass(SOBCoin);

    SOBCoin::SOBCoin(Context* context) : MovableEntity(context)
    {
        RegisterObject(SOBCoin);
        setAngularFactor(0.0);

    }

    
    void SOBCoin::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(SOBCoin, XMLPort, xmlelement, mode);
        XMLPortParam(SOBCoin, "lifetime", setLifetime, getLifetime, xmlelement, mode);
        XMLPortParam(SOBCoin, "speed", setSpeed, getSpeed, xmlelement, mode);

    }


    void SOBCoin::tick(float dt)
    {
        SUPER(SOBCoin, tick, dt);

        lifetime_-=dt;

        if (lifetime_ <+ 0) {
            destroyLater();
        }

        Vector3 velocity = getVelocity();
        velocity.z = speed_;
        setOrientation(Vector3::UNIT_Z, getOrientation().getRoll() + 2*dt*Radian(6));
        setVelocity(velocity);



    }


}
